==> pycm-2.7.tar.gz: pycm-2.7/TODO.md <==
## Todo

- [x] Basic
  - [x] TP
  - [x] FP
  - [x] FN
  - [x] TN
  - [x] Population
  - [x] Condition positive
  - [x] Condition negative 
  - [x] Test outcome positive
  - [x] Test outcome negative
- [x] Class Statistics
  - [x] ACC
  - [x] ERR
  - [x] BM
  - [x] DOR
  - [x] F1-Score
  - [x] FDR
  - [x] FNR
  - [x] FOR
  - [x] FPR
  - [x] LR+
  - [x] LR-
  - [x] MCC
  - [x] MK
  - [x] NPV
  - [x] PPV
  - [x] TNR
  - [x] TPR
  - [x] Prevalence
  - [x] G-measure
  - [x] RACC
  - [x] CEN
  - [x] MCEN
  - [x] IS
  - [x] AUC
  - [x] dlnd
  - [x] slnd
  - [x] DP
  - [x] Y
  - [x] DPI
  - [x] PLRI
  - [x] AUCI
  - [x] GI
  - [x] LS
  - [x] A/M
  - [x] BCD
  - [x] OP
  - [x] IBA
  - [x] GM
  - [x] Q
  - [x] AGM
- [x] Outputs
  - [x] CSV File
  - [x] HTML File
  - [x] Output File
  - [x] Table
  - [x] Normalized Table
- [x] Overall Statistics
  - [x] CI
  - [x] Chi-Squared
  - [x] Phi-Squared
  - [x] Cramer's V
  - [x] Kappa
  - [x] Kappa Unbiased
  - [x] Kappa No Prevalence
  - [ ] Aickin's alpha
  - [x] Bennett S score
  - [x] Gwet's AC1
  - [x] Scott's pi
  - [ ] Krippendorff's alpha
  - [x] Goodman and Kruskal's lambda A
  - [x] Goodman and Kruskal's lambda B
  - [x] Kullback-Liebler divergence
  - [x] Entropy
  - [x] Overall ACC
  - [x] Strength of Agreement
    - [x] Landis and Koch
    - [x] Fleiss
    - [x] Altman
    - [x] Cicchetti 
  - [x] TPR Micro/Macro
  - [x] PPV Micro/Macro
  - [x] Jaccard Index
  - [x] Hamming Loss
  - [x] Zero-One Loss
  - [x] P-Value
  - [x] NIR
  - [x] Overall CEN
  - [x] Overall MCEN
  - [x] AUNU
  - [x] AUNP
  - [x] Overall MCC
  - [x] CBA
  - [x] RCI
  - [x] Pearson's C

==> pycm-2.8.tar.gz: pycm-2.8/TODO.md <==
## Todo

- [x] Basic
  - [x] TP
  - [x] FP
  - [x] FN
  - [x] TN
  - [x] Population
  - [x] Condition positive
  - [x] Condition negative 
  - [x] Test outcome positive
  - [x] Test outcome negative
- [x] Class Statistics
  - [x] ACC
  - [x] ERR
  - [x] BM
  - [x] DOR
  - [x] F1-Score
  - [x] FDR
  - [x] FNR
  - [x] FOR
  - [x] FPR
  - [x] LR+
  - [x] LR-
  - [x] MCC
  - [x] MK
  - [x] NPV
  - [x] PPV
  - [x] TNR
  - [x] TPR
  - [x] Prevalence
  - [x] G-measure
  - [x] RACC
  - [x] CEN
  - [x] MCEN
  - [x] IS
  - [x] AUC
  - [x] dlnd
  - [x] slnd
  - [x] DP
  - [x] Y
  - [x] DPI
  - [x] PLRI
  - [x] AUCI
  - [x] GI
  - [x] LS
  - [x] A/M
  - [x] BCD
  - [x] OP
  - [x] IBA
  - [x] GM
  - [x] Q
  - [x] AGM
- [x] Outputs
  - [x] CSV File
  - [x] HTML File
  - [x] Output File
  - [x] Table
  - [x] Normalized Table
- [x] Overall Statistics
  - [x] CI
  - [x] Chi-Squared
  - [x] Phi-Squared
  - [x] Cramer's V
  - [x] Kappa
  - [x] Kappa Unbiased
  - [x] Kappa No Prevalence
  - [x] Aickin's alpha
  - [x] Bennett S score
  - [x] Gwet's AC1
  - [x] Scott's pi
  - [x] Krippendorff's alpha
  - [x] Goodman and Kruskal's lambda A
  - [x] Goodman and Kruskal's lambda B
  - [x] Kullback-Liebler divergence
  - [x] Entropy
  - [x] Overall ACC
  - [x] Strength of Agreement
    - [x] Landis and Koch
    - [x] Fleiss
    - [x] Altman
    - [x] Cicchetti 
  - [x] TPR Micro/Macro
  - [x] PPV Micro/Macro
  - [x] Jaccard Index
  - [x] Hamming Loss
  - [x] Zero-One Loss
  - [x] P-Value
  - [x] NIR
  - [x] Overall CEN
  - [x] Overall MCEN
  - [x] AUNU
  - [x] AUNP
  - [x] Overall MCC
  - [x] CBA
  - [x] RCI
  - [x] Pearson's C
